[edk2-devel] [PATCH v1 2/3] MdeModulePkg/Graphics: Fix spelling mistakes

Samer El-Haj-Mahmoud samer.el-haj-mahmoud at arm.com
Tue Nov 24 19:15:45 UTC 2020


Fix various spelling mistakes in GraphicsConsoleDxe, ConsPlitter,
and SimpleTextOut header

Cc: Jian J Wang <jian.j.wang at intel.com>
Cc: Hao A Wu <hao.a.wu at intel.com>
Cc: Zhichao Gao <zhichao.gao at intel.com>
Cc: Ray Ni <ray.ni at intel.com>
Cc: Ard Biesheuvel <Ard.Biesheuvel at arm.com>
Cc: Pete Batard <pete at akeo.ie>
Signed-off-by: Samer El-Haj-Mahmoud <Samer.El-Haj-Mahmoud at arm.com>
---
 MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.h |  8 +--
 MdePkg/Include/Protocol/SimpleTextOut.h                             |  6 +-
 MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitter.c         | 66 ++++++++++----------
 MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c | 12 ++--
 4 files changed, 46 insertions(+), 46 deletions(-)

diff --git a/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.h b/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.h
index 28d47ac7cb1e..11d254b70f32 100644
--- a/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.h
+++ b/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.h
@@ -205,7 +205,7 @@ GraphicsConsoleComponentNameGetControllerName (
   Reset the text output device hardware and optionally run diagnostics.
 
   Implements SIMPLE_TEXT_OUTPUT.Reset().
-  If ExtendeVerification is TRUE, then perform dependent Graphics Console
+  If ExtendedVerification is TRUE, then perform dependent Graphics Console
   device reset, and set display mode to mode 0.
   If ExtendedVerification is FALSE, only set display mode to mode 0.
 
@@ -286,7 +286,7 @@ GraphicsConsoleConOutTestString (
   supports
 
   Implements SIMPLE_TEXT_OUTPUT.QueryMode().
-  It returnes information for an available text mode that the Graphics Console supports.
+  It returns information for an available text mode that the Graphics Console supports.
   In this driver,we only support text mode 80x25, which is defined as mode 0.
 
   @param  This                  Protocol instance pointer.
@@ -422,7 +422,7 @@ GraphicsConsoleConOutEnableCursor (
 /**
   Test to see if Graphics Console could be supported on the Controller.
 
-  Graphics Console could be supported if Graphics Output Protocol or UGA Draw
+  Graphics Console could be supported if Graphics Output Protocol or UGADraw
   Protocol exists on the Controller. (UGA Draw Protocol could be skipped
   if PcdUgaConsumeSupport is set to FALSE.)
 
@@ -510,7 +510,7 @@ EfiLocateHiiProtocol (
 
 
 /**
-  Gets Graphics Console devcie's foreground color and background color.
+  Gets Graphics Console device's foreground color and background color.
 
   @param  This                  Protocol instance pointer.
   @param  Foreground            Returned text foreground color.
diff --git a/MdePkg/Include/Protocol/SimpleTextOut.h b/MdePkg/Include/Protocol/SimpleTextOut.h
index a849c08d66df..100d69a23a9b 100644
--- a/MdePkg/Include/Protocol/SimpleTextOut.h
+++ b/MdePkg/Include/Protocol/SimpleTextOut.h
@@ -32,7 +32,7 @@ typedef struct _EFI_SIMPLE_TEXT_OUTPUT_PROTOCOL EFI_SIMPLE_TEXT_OUTPUT_PROTOCOL;
 typedef EFI_SIMPLE_TEXT_OUTPUT_PROTOCOL   SIMPLE_TEXT_OUTPUT_INTERFACE;
 
 //
-// Define's for required EFI Unicode Box Draw characters
+// Defines for required EFI Unicode Box Draw characters
 //
 #define BOXDRAW_HORIZONTAL                  0x2500
 #define BOXDRAW_VERTICAL                    0x2502
@@ -151,7 +151,7 @@ typedef EFI_SIMPLE_TEXT_OUTPUT_PROTOCOL   SIMPLE_TEXT_OUTPUT_INTERFACE;
 #define EFI_WIDE_ATTRIBUTE  0x80
 
 /**
-  Reset the text output device hardware and optionaly run diagnostics
+  Reset the text output device hardware and optionally run diagnostics
 
   @param  This                 The protocol instance pointer.
   @param  ExtendedVerification Driver may perform more exhaustive verification
@@ -373,7 +373,7 @@ typedef struct {
   ///
   INT32   CursorRow;
   ///
-  /// The cursor is currently visbile or not.
+  /// The cursor is currently visible or not.
   ///
   BOOLEAN CursorVisible;
 } EFI_SIMPLE_TEXT_OUTPUT_MODE;
diff --git a/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c b/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c
index 6b8d11d587d1..d6d8db51d5e9 100644
--- a/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c
+++ b/MdeModulePkg/Universal/Console/GraphicsConsoleDxe/GraphicsConsole.c
@@ -214,7 +214,7 @@ Error:
 
   @param[in]  HorizontalResolution     The size of video screen in pixels in the X dimension.
   @param[in]  VerticalResolution       The size of video screen in pixels in the Y dimension.
-  @param[in]  GopModeNumber            The graphics mode number which graphis console is based on.
+  @param[in]  GopModeNumber            The graphics mode number which graphics console is based on.
   @param[out] TextModeCount            The total number of text modes that graphics console supports.
   @param[out] TextModeData             The buffer to the text modes column and row information.
                                        Caller is responsible to free it when it's non-NULL.
@@ -491,7 +491,7 @@ GraphicsConsoleControllerDriverStart (
         Mode = Private->GraphicsOutput->Mode;
         if (EFI_ERROR (Status) && Mode->MaxMode != 0) {
           //
-          // Set default mode failed or device don't support default mode, then get the current mode information
+          // If set default mode failed or device doesn't support default mode, then get the current mode information
           //
           HorizontalResolution = Mode->Info->HorizontalResolution;
           VerticalResolution = Mode->Info->VerticalResolution;
@@ -501,7 +501,7 @@ GraphicsConsoleControllerDriverStart (
     }
     if (ModeNumber != Private->GraphicsOutput->Mode->Mode) {
       //
-      // Current graphics mode is not set or is not set to the mode which we has found,
+      // Current graphics mode is not set or is not set to the mode which we have found,
       // set the new graphic mode.
       //
       Status = Private->GraphicsOutput->SetMode (Private->GraphicsOutput, ModeNumber);
@@ -740,7 +740,7 @@ GraphicsConsoleControllerDriverStop (
   Check if the current specific mode supported the user defined resolution
   for the Graphics Console device based on Graphics Output Protocol.
 
-  If yes, set the graphic devcice's current mode to this specific mode.
+  If yes, set the graphic device's current mode to this specific mode.
 
   @param  GraphicsOutput        Graphics Output Protocol instance pointer.
   @param  HorizontalResolution  User defined horizontal resolution
@@ -843,7 +843,7 @@ EfiLocateHiiProtocol (
   Reset the text output device hardware and optionally run diagnostics.
 
   Implements SIMPLE_TEXT_OUTPUT.Reset().
-  If ExtendeVerification is TRUE, then perform dependent Graphics Console
+  If ExtendedVerification is TRUE, then perform dependent Graphics Console
   device reset, and set display mode to mode 0.
   If ExtendedVerification is FALSE, only set display mode to mode 0.
 
@@ -1713,7 +1713,7 @@ GraphicsConsoleConOutEnableCursor (
 }
 
 /**
-  Gets Graphics Console devcie's foreground color and background color.
+  Gets Graphics Console device's foreground color and background color.
 
   @param  This                  Protocol instance pointer.
   @param  Foreground            Returned text foreground color.
diff --git a/MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitter.c b/MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitter.c
index 9c38271b65f9..b090de288517 100644
--- a/MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitter.c
+++ b/MdeModulePkg/Universal/Console/ConSplitterDxe/ConSplitter.c
@@ -1,5 +1,5 @@
 /** @file
-  Console Splitter Driver. Any Handle that attatched console I/O protocols
+  Console Splitter Driver. Any Handle that attached console I/O protocols
   (Console In device, Console Out device, Console Error device, Simple Pointer
   protocol, Absolute Pointer protocol) can be bound by this driver.
 
@@ -13,7 +13,7 @@
 
   Each virtual handle, that supports the Console I/O protocol, will be produced
   in the driver entry point. The virtual handle are added on driver entry and
-  never removed. Such design ensures sytem function well during none console
+  never removed. Such design ensures system function well during none console
   device situation.
 
 Copyright (c) 2006 - 2019, Intel Corporation. All rights reserved.<BR>
@@ -381,7 +381,7 @@ ToggleStateSyncInitialization (
 }
 
 /**
-  Reinitialization for toggle state sync.
+  Re-initialization for toggle state sync.
 
   @param Private                    Text In Splitter pointer.
 
@@ -594,7 +594,7 @@ ConSplitterDriverEntry(
                                    structure.
 
   @retval EFI_OUT_OF_RESOURCES     Out of resources.
-  @retval EFI_SUCCESS              Text Input Devcie's private data has been constructed.
+  @retval EFI_SUCCESS              Text Input Device's private data has been constructed.
   @retval other                    Failed to construct private data.
 
 **/
@@ -761,7 +761,7 @@ ConSplitterTextOutConstructor (
   }
 
   //
-  // Initilize console output splitter's private data.
+  // Initialize console output splitter's private data.
   //
   ConOutPrivate->TextOut.Mode = &ConOutPrivate->TextOutMode;
 
@@ -860,7 +860,7 @@ ConSplitterTextOutConstructor (
   @param  Guid                The specified protocol.
 
   @retval EFI_SUCCESS         The specified protocol is supported on this device.
-  @retval EFI_UNSUPPORTED     The specified protocol attempts to be installed on virtul handle.
+  @retval EFI_UNSUPPORTED     The specified protocol attempts to be installed on virtual handle.
   @retval other               Failed to open specified protocol on this device.
 
 **/
@@ -1108,7 +1108,7 @@ ConSplitterStart (
   }
 
   //
   // Open InterfaceGuid on the virtul handle.
   //
   Status =  gBS->OpenProtocol (
                 ControllerHandle,
@@ -1174,7 +1174,7 @@ ConSplitterConInDriverBindingStart (
 
   //
   // Start ConSplitter on ControllerHandle, and create the virtual
-  // agrogated console device on first call Start for a SimpleTextIn handle.
+  // aggregated console device on first call Start for a SimpleTextIn handle.
   //
   Status = ConSplitterStart (
             This,
@@ -1241,7 +1241,7 @@ ConSplitterSimplePointerDriverBindingStart (
 
   //
   // Start ConSplitter on ControllerHandle, and create the virtual
-  // agrogated console device on first call Start for a SimplePointer handle.
+  // aggregated console device on first call Start for a SimplePointer handle.
   //
   Status = ConSplitterStart (
             This,
@@ -1287,7 +1287,7 @@ ConSplitterAbsolutePointerDriverBindingStart (
 
   //
   // Start ConSplitter on ControllerHandle, and create the virtual
-  // agrogated console device on first call Start for a AbsolutePointer handle.
+  // aggregated console device on first call Start for a AbsolutePointer handle.
   //
   Status = ConSplitterStart (
              This,
@@ -1338,7 +1338,7 @@ ConSplitterConOutDriverBindingStart (
 
   //
   // Start ConSplitter on ControllerHandle, and create the virtual
-  // agrogated console device on first call Start for a ConsoleOut handle.
+  // aggregated console device on first call Start for a ConsoleOut handle.
   //
   Status = ConSplitterStart (
             This,
@@ -1451,7 +1451,7 @@ ConSplitterStdErrDriverBindingStart (
 
   //
   // Start ConSplitter on ControllerHandle, and create the virtual
-  // agrogated console device on first call Start for a StandardError handle.
+  // aggregated console device on first call Start for a StandardError handle.
   //
   Status = ConSplitterStart (
             This,
@@ -1522,7 +1522,7 @@ ConSplitterStop (
     return Status;
   }
   //
-  // close the protocol refered.
+  // close the protocol referred.
   //
   gBS->CloseProtocol (
         ControllerHandle,
@@ -1543,7 +1543,7 @@ ConSplitterStop (
 
 
 /**
-  Stop Console In ConSplitter on ControllerHandle by closing Console In Devcice GUID.
+  Stop Console In ConSplitter on ControllerHandle by closing Console In Device GUID.
 
   @param  This              Driver Binding protocol instance pointer.
   @param  ControllerHandle  Handle of device to stop driver on
@@ -1718,7 +1718,7 @@ ConSplitterAbsolutePointerDriverBindingStop (
 
 
 /**
-  Stop Console Out ConSplitter on device handle by closing Console Out Devcice GUID.
+  Stop Console Out ConSplitter on device handle by closing Console Out Devcie GUID.
 
   @param  This              Driver Binding protocol instance pointer.
   @param  ControllerHandle  Handle of device to stop driver on
@@ -2725,7 +2725,7 @@ ConSplitterGetIntersectionBetweenConOutAndStrErr (
 
 
 /**
-  Add Grahpics Output modes into Consplitter Text Out list.
+  Add Graphics Output modes into Consplitter Text Out list.
 
   @param  Private               Text Out Splitter pointer.
   @param  GraphicsOutput        Graphics Output protocol pointer.
@@ -3392,7 +3392,7 @@ ConSplitterTextOutDeleteDevice (
     return EFI_SUCCESS;
   }
   //
-  // Max Mode is realy an intersection of the QueryMode command to all
+  // Max Mode is really an intersection of the QueryMode command to all
   // devices. So we must copy the QueryMode of the first device to
   // QueryData.
   //
@@ -3430,7 +3430,7 @@ ConSplitterTextOutDeleteDevice (
 
 
 /**
-  Reset the input device and optionaly run diagnostics
+  Reset the input device and optionally run diagnostics
 
   @param  This                     Protocol instance pointer.
   @param  ExtendedVerification     Driver may perform diagnostics on reset.
@@ -3514,7 +3514,7 @@ ConSplitterTextInExDequeueKey (
 
 /**
   Reads the next keystroke from the input device. The WaitForKey Event can
-  be used to test for existance of a keystroke via WaitForEvent () call.
+  be used to test for existence of a keystroke via WaitForEvent () call.
 
   @param  Private                  Protocol instance pointer.
   @param  Key                      Driver may perform diagnostics on reset.
@@ -3587,7 +3587,7 @@ ConSplitterTextInPrivateReadKeyStroke (
 
 /**
   Reads the next keystroke from the input device. The WaitForKey Event can
-  be used to test for existance of a keystroke via WaitForEvent () call.
+  be used to test for existence of a keystroke via WaitForEvent () call.
 
   @param  This                     Protocol instance pointer.
   @param  Key                      Driver may perform diagnostics on reset.
@@ -3631,7 +3631,7 @@ ConSplitterTextInReadKeyStroke (
   spliter event. This will cause the calling code to call
   ConSplitterTextInReadKeyStroke ().
 
-  @param  Event                    The Event assoicated with callback.
+  @param  Event                    The Event associated with callback.
   @param  Context                  Context registered when Event was created.
 
 **/
@@ -3681,7 +3681,7 @@ ConSplitterTextInWaitForKey (
                                    pressed.
 
   @retval TRUE                     Key be pressed matches a registered key.
-  @retval FLASE                    Match failed.
+  @retval FALSE                    Match failed.
 
 **/
 BOOLEAN
@@ -3715,7 +3715,7 @@ IsKeyRegistered (
 
 
 /**
-  Reset the input device and optionaly run diagnostics
+  Reset the input device and optionally run diagnostics
 
   @param  This                     Protocol instance pointer.
   @param  ExtendedVerification     Driver may perform diagnostics on reset.
@@ -3769,7 +3769,7 @@ ConSplitterTextInResetEx (
 
 /**
   Reads the next keystroke from the input device. The WaitForKey Event can
-  be used to test for existance of a keystroke via WaitForEvent () call.
+  be used to test for existence of a keystroke via WaitForEvent () call.
 
   @param  This                     Protocol instance pointer.
   @param  KeyData                  A pointer to a buffer that is filled in with the
@@ -3978,7 +3978,7 @@ ConSplitterTextInSetState (
 
   @retval EFI_SUCCESS              The notification function was registered
                                    successfully.
-  @retval EFI_OUT_OF_RESOURCES     Unable to allocate resources for necesssary data
+  @retval EFI_OUT_OF_RESOURCES     Unable to allocate resources for necessary data
                                    structures.
   @retval EFI_INVALID_PARAMETER    KeyData or KeyNotificationFunction or NotifyHandle is NULL.
 
@@ -4126,7 +4126,7 @@ ConSplitterTextInUnregisterKeyNotify (
 
 
 /**
-  Reset the input device and optionaly run diagnostics
+  Reset the input device and optionally run diagnostics
 
   @param  This                     Protocol instance pointer.
   @param  ExtendedVerification     Driver may perform diagnostics on reset.
@@ -4174,7 +4174,7 @@ ConSplitterSimplePointerReset (
 
 /**
   Reads the next keystroke from the input device. The WaitForKey Event can
-  be used to test for existance of a keystroke via WaitForEvent () call.
+  be used to test for existence of a keystroke via WaitForEvent () call.
 
   @param  Private                  Protocol instance pointer.
   @param  State                    The state information of simple pointer device.
@@ -4279,12 +4279,12 @@ ConSplitterSimplePointerGetState (
 
 
 /**
-  This event agregates all the events of the ConIn devices in the spliter.
+  This event aggregates all the events of the ConIn devices in the spliter.
   If any events of physical ConIn devices are signaled, signal the ConIn
   spliter event. This will cause the calling code to call
   ConSplitterTextInReadKeyStroke ().
 
-  @param  Event                    The Event assoicated with callback.
+  @param  Event                    The Event associated with callback.
   @param  Context                  Context registered when Event was created.
 
 **/
@@ -4493,12 +4493,12 @@ ConSplitterAbsolutePointerGetState (
 
 
 /**
-  This event agregates all the events of the pointer devices in the splitter.
+  This event aggregates all the events of the pointer devices in the splitter.
   If any events of physical pointer devices are signaled, signal the pointer
   splitter event. This will cause the calling code to call
   ConSplitterAbsolutePointerGetState ().
 
-  @param  Event                    The Event assoicated with callback.
+  @param  Event                    The Event associated with callback.
   @param  Context                  Context registered when Event was created.
 
 **/
@@ -4537,10 +4537,10 @@ ConSplitterAbsolutePointerWaitForInput (
 
 
 /**
-  Reset the text output device hardware and optionaly run diagnostics
+  Reset the text output device hardware and optionally run diagnostics
 
   @param  This                     Protocol instance pointer.
-  @param  ExtendedVerification     Driver may perform more exhaustive verfication
+  @param  ExtendedVerification     Driver may perform more exhaustive verification
                                    operation of the device during reset.
 
   @retval EFI_SUCCESS              The text output device was reset.
@@ -1108,7 +1108,7 @@ ConSplitterStart (
 
   //
-  // Open InterfaceGuid on the virtul handle.
+  // Open InterfaceGuid on the virtual handle.
   //
   Status =  gBS->OpenProtocol (
-- 
2.25.1



-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.
View/Reply Online (#67907): https://edk2.groups.io/g/devel/message/67907
Mute This Topic: https://groups.io/mt/78484574/1813853
Group Owner: devel+owner at edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub [edk2-devel-archive at redhat.com]
-=-=-=-=-=-=-=-=-=-=-=-






More information about the edk2-devel-archive mailing list